@@ -6,8 +6,13 @@
 from translate import Translator as t
 import googletrans as g
 
-# Manager
-import manager as m
+
+
+managers = {
+      # Translate
+      "from": None,
+      "to": None,
+}
 
 
 
@@ -18,10 +23,10 @@ import manager as m
 # TRANSLATOR
 def translate(text, fr, to):
       
-      m.managers['from'] = fr
-      m.managers['to'] = to
+      managers['from'] = fr
+      managers['to'] = to
 
-      translator = t(from_lang=m.managers['from'], to_lang=m.managers['to'])
+      translator = t(from_lang=managers['from'], to_lang=managers['to'])
       translation = translator.translate(text)
 
       return translation
