@@ -6,8 +6,11 @@
 # API
 import wikipedia as w
 
-# Manager
-import manager as m
+
+
+managers = {
+      "sentences": 2,
+}
 
 
 
@@ -17,5 +20,5 @@ import manager as m
 def search(page):
 
       # Search
-      return w.summary(page, sentences=m.managers['sentences'])
+      return w.summary(page, sentences=managers['sentences'])
 
